%% Project OD. Figure 2
% DESCRIPTION: Ocular dominance index by penetration, and V1 responses to
% all 36 conditions. 
% Compatible with ODproject_MUA workspace. 

% figure style
set(0,'DefaultFigureWindowStyle','normal') 
flag_save = 1;

% save directory
if flag_save == 1 
    USER = getenv('username');
    figDir = strcat('C:\Users\',USER,'\OneDrive - Vanderbilt\Data Analysis\Figures\OD Project\');
    cd(figDir);
    disp("Figure directory created");
end

%% 1. Ocular dominance session breakdown

unique_pens = string(unique({IDX.penetration}));

pen_idx = [1,21;... 1
          22,22;... 2
          23,34;... 3
          35,41;... 4
          42,57;...5
          58,73;...6
          74,74;...7
          75,83;...8
          84,98;...9 % end of B
          99,127;...10
          128,146;...11
          147,169;...12
          170,194;...13
          195,222;...14
          223,250;...15
          251,276;...16
          277,305;...17
          306,334;...18
          335,355;...19
          356,376;...20
          377,401;...21
          402,422;...22
          423,444;...23
          445,473;...24
          474,502];...25
      
clear occ occ2 pen_occ
occ = [IDX.X];
occ2 = [occ.occ_norm]';
occ2(1:98) = occ2(1:98) .*-1; % this flips B52's values to be consistent with Jo's, to account for which hemisphere the chamber was on

for i = 1:length(pen_idx)
    pen_occ{i} = occ2(pen_idx(i,1):pen_idx(i,2));
end

% re-order so that Jo's data is first
temp = pen_occ(1:9);

pen_occ(1:9) = [];

pen_occ = [pen_occ temp];

% Counts
occ_percentage_contra = length(occ2(occ2 > 0)) / length(occ2);
occ_percentage_ipsi = length(occ2(occ2 < 0)) / length(occ2);

%% Ocular dominance by penetration figure

close all
figure('position',[1435,426,437,343]);
set(gca,'ylim',[-1 1],'xlim',[0 26],'linewidth',1.5,'fontsize',10,'box','off');
ylabel('Ocular Dominance'); xlabel('Penetration #');
hl = hline(0); set(hl,'linestyle',':','color','k'); hold on

for u = 1:length(pen_occ)
    h = plot(u,pen_occ{u},'.','linestyle','none'); hold on
    
    if u <= 16
        set(h,'Color',[colors.green,0.2]);
    else
        set(h,'Color',[colors.purple,0.2]);
    end
end
    

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxPenetration','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% 2. Ocular dominance histogram - vertical

OCC   = getOCC(UNIT,[],IDX,[], info,3 ,'diUnitTuning_norm');

figure('position',[355,499,194,316]);
nbin = 15;
tw = 12;

    histogram(OCC.ocularity(J_units),nbin,'binWidth',0.025,'faceAlpha',0.8,'linewidth',0.75,...
        'faceColor',colors.green,'edgecolor','none','edgealpha',0.5,'facealpha',0.5,'orientation','horizontal'); hold on % binsize 0.02 for orig figure
    
        histogram(OCC.ocularity(~J_units).*-1,nbin,'binWidth',0.045,'faceAlpha',0.8,'linewidth',0.75,...
        'faceColor',colors.purple,'edgecolor','none','edgealpha',0.8,'facealpha',0.5,'orientation','horizontal'); hold on
    
set(gca,'ylim',[-1 1],'xlim',[0 45],'linewidth',1.5,'fontsize',10,'box','off');
ylabel('Ocular dominance'); xlabel('# of units');
xticks([0:20:40]);

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ocular_dominance_histogram_single_units','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

% descriptive statistics
occ_stats.mean = mean(OCC.ocularity);
occ_stats.sd = std(OCC.ocularity);
occ_stats.kurtosis = kurtosis(OCC.ocularity);
occ_stats.skew = skewness(OCC.ocularity);


%% 3. V1 SDFs sorted by contrast shown to DE

close all
clear DI
for i = 1:length(UNIT)
    DI.units(:,:,i)  = UNIT(i).DI.SDF_avg; 
end


DI.avg  = nanmean(DI.units,3);
DI.avg_flip = flipud(DI.avg);
p = 90;
clear CI*
for i = 1:size(DI.units,2)
    for c = 1:size(DI.units,1)
        CI_DI{c}(:,i) = CIFcn(DI.units(c,i,:),p); 
    end
end

CI_DI_flip = fliplr(CI_DI);

if length(info.diLevels) == 25
color_vector = [colors.black;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.blue;...
                colors.black;
                colors.dark_red;...
                colors.dark_red;...
                colors.blue;...
                colors.dark_red;...
                colors.black;...
                colors.dark_red;...
                colors.blue;...
                colors.dark_red;...
                colors.dark_red;...
                colors.black;...
                colors.blue;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.black;...
                colors.black;...
                colors.black;...
                colors.black;...
                colors.black];

response_vector = [5,10,15,20,25,...
                4,9,14,19,24,...
                3,8,13,18,23,...
                2,7,12,17,22,...
                1,6,11,16,21];

elseif length(info.diLevels) == 36


response_vector = [6,12,18,24,30,36,...
                5,11,17,23,29,35,...
                4,10,16,22,28,34,...
                3,9,15,21,27,33,...
                2,8,14,20,26,32,...
                1,7,13,19,25,31];

color_vector = [colors.black;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.blue;...

                colors.black;
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.blue;...
                colors.dark_red;...

                colors.black;...
                colors.dark_red;...
                colors.dark_red;...
                colors.blue;...
                colors.dark_red;...
                colors.dark_red;...

                colors.black;...
                colors.dark_red;...
                colors.blue;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...

                colors.black;...
                colors.blue;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                colors.dark_red;...
                
                colors.black;...
                colors.black;...
                colors.black;...
                colors.black;...
                colors.black;...
                colors.black];

end

figure('position',[1080.333333333333,385,1097.333333333333,671.3333333333333]);
ylimit = [-0.02 1.7];
xlimit = [-0.05 .200];
% subplot 1
for c = 1:size(DI.units,1)
    idx = response_vector(c);
    subplot(length(info.cLevels),length(info.cLevels),c,'replace')
    % Plot 1
    title(num2str(c))

    plot(info.sdfWin,DI.avg(idx,:),'color',color_vector(c,:),'linewidth',1.5); hold on
    ci1 = ciplot(CI_DI{idx}(1,:),CI_DI{idx}(2,:),info.sdfWin,color_vector(c,:),0.3);
    set(ci1,'linestyle','none','handleVisibility','off');
    ax = gca;
    ax.YGrid = 'on';
    ax.XGrid = 'off';
    % y label
    if c == 1 || c == 7 || c == 13 || c == 19 || c == 25 
        xticklabels([]);
    elseif c == 31
        xlabel('Time (s)');
        ylabel('V1 MUA (norm.)')

    elseif c > 30
        ylabel([]); xlabel([]);
        yticklabels([]);
    else
        ylabel([]); xlabel([]);
        xticklabels([]); yticklabels([]);
    end

    yticks([0,1.3,1.7])
    set(gca,'Box','off','TickDir','out','linewidth',1.2,'ylim',ylimit,'xlim',xlimit,...
        'Fontsize',14)
        vl = vline(0); hold on
    set(vl,'linestyle','--','color',[0.2,0.2,0.2]);
    %yticks([0, 50, 100, 150, 200]);
    %title([num2str(info.diLevels(c,1)),' | ',num2str(info.diLevels(c,2))])
    
end

if flagsave == 1
    cd(figDir)
    saveas(gcf, strcat('SDF_grid_responses_fixed','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


%% Ratio of units preferring contra / ipsi 
for p = 1:length(pen_occ)
    pen_occ_avg(p) = mean(pen_occ{p});
end

contra_idx = pen_occ_avg > 0;
ipsi_idx = pen_occ_avg < 0;

column_ratio = sum(contra_idx) / length(pen_occ_avg);

% Grab percentage of units preferring contralateral eye
contra_n = OCC.ocularity > 0; 
ipsi_n = OCC.ocularity < 0;

unit_ratio = sum(contra_n) / length(OCC.ocularity);

