%% Project OD. Figure 4. 
% DESCRIPTION: Asymmetry indices (response and summation) x OD
% Compatible with ODproject_MUA workspace. 

% Calculate ocular dominance
if ~exist('OCC','var')
    OCC   = getOCC(UNIT,[],IDX,[], info,3 ,'diUnitTuning_norm'); % OD normalized to stimulus contrast 
end

if~exist('paired_response_sum','var')
    error('Asymmetry indices not yet calculated. Run F3_ProjectOD_asymmetry.m first');
end

% Ocular dominance x response asymmetry 

figure('position',[681,702,383,277]);
hl = hline(0); hold on
set(hl,'color','k');
s =scatter(OCC.ocularity_abs,paired_response_sum.unit'); hold on
set(gca,'ylim',[-0.4,0.4],'xlim',[0 1]);


clear mdl
 x = squeeze(OCC.ocularity_abs); y = paired_response_sum.unit';
 mdl = fitlm(x,y);
 stats.resp_asymmetry.r2 = mdl.Rsquared.Adjusted;
 stats.resp_asymmetry.t = mdl.Coefficients(2,3);
 stats.resp_asymmetry.p = mdl.Coefficients(2,4);
 
 h = plot(mdl);
 ylabel('Response asymmetry')
 xlabel('| Ocular dominance |');
 legend off
 axis square
 
 s(1).Marker = 'o';
 set(s,'MarkerFaceAlpha',0.3);

     h(1).Marker = 'o';
     s(1).MarkerFaceColor = colors.blue;
     s(1).MarkerEdgeColor = 'none';
     h(1).Color = 'none';

 if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxResponse_',string(tw),'.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
 end

 %% Ocular dominance x summation asymmetry 

figure('position',[681,702,383,277]);
hl = hline(0); hold on
set(hl,'color','k');
s =scatter(OCC.ocularity_abs,paired_summation_sum.unit'); hold on
set(gca,'ylim',[-0.31,0.31],'xlim',[0 1]);


clear mdl
 x = squeeze(OCC.ocularity_abs); y = paired_summation_sum.unit';
 mdl = fitlm(x,y,'exclude',y > 0.4);
 CI = coefCI(mdl);
 stats.sum_asymmetry.r2 = mdl.Rsquared.Adjusted;
 stats.sum_asymmetry.t = mdl.Coefficients(2,3);
 stats.sum_asymmetry.p = mdl.Coefficients(2,4);

 
 h = plot(mdl);
 ylabel('Summation Asymmetry')
 xlabel('| Ocular dominance |');
 legend off
 axis square
 
 s(1).Marker = 'o';
 set(s,'MarkerFaceAlpha',0.3);

 h(1).Marker = 'o';
 s(1).MarkerFaceColor = colors.orange;
 s(1).MarkerEdgeColor = 'none';
 h(1).Color = 'none';

 if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxSummation_',string(tw),'.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
 end

