%% Project OD. Figure 5. 
% DESCRIPTION: V1 Monocular Contrast response functions (CRFs).
% Compatible with ODproject_MUA workspace. 

% figure style
set(0,'DefaultFigureWindowStyle','normal') 
set(groot, 'DefaultAxesTickLabelInterpreter', 'none')
flag_save = 1;

% save directory
if flag_save == 1 
    USER = getenv('username');
    figDir = strcat('C:\Users\',USER,'\OneDrive - Vanderbilt\Data Analysis\Figures\OD Project\');
    cd(figDir);
    disp("Figure directory created");
end

% mean CRF fit
if ~exist('uCRF','var')
    uCRF = fitMeanCRF(UNIT,IDX,info,'norm');
end

%% Monocular CRFs: Population
close all
figure('position',[386.3333333333333,613,421.6666666666667,383]);
ylimit = 1;
tw = 12;

% Datapoints
x = 0.01:.01:1; contrast = [0.01, 0.055, 0.11, 0.225, 0.45, 0.90];
plot(contrast,uCRF.DE.data(:,tw,1),'o','MarkerFaceColor',colors.black,'color',colors.black,'linestyle','none'); hold on
errorbar(contrast, uCRF.DE.data(:,tw,1), uCRF.DE.sem(:,tw).*2,'linestyle','none','color',colors.black,'handleVisibility','off');
errorbar(contrast, uCRF.NDE.data(:,tw,1), uCRF.NDE.sem(:,tw).*2,'linestyle','none','color',colors.black,'handleVisibility','off');
plot(contrast,uCRF.NDE.data(:,tw,1),'o','MarkerFaceColor',[1 1 1],'color',colors.black,'linestyle','none');

% Curve fit
plot(x, uCRF.DE.curve(:,tw,1),'color',colors.black,'linestyle','-','linewidth',1); hold on
ci1 = ciplot(uCRF.DE.curve(:,tw,2),uCRF.DE.curve(:,tw,3),x,colors.black,0.1);
set(ci1,'linestyle','none','edgecolor',colors.black,'linewidth',1,'handleVisibility','off'); hold on
plot(x, uCRF.NDE.curve(:,tw,1),'color',colors.black,'linestyle','-','linewidth',1); hold on
ci2 = ciplot(uCRF.NDE.curve(:,tw,2),uCRF.NDE.curve(:,tw,3),x,colors.black,0.1);
set(ci2,'linestyle','none','edgecolor',colors.black,'linewidth',1,'handleVisibility','off'); hold on
%plot(x, CRF2.BIN.curve_avg(:,tw),'color',colors.dark_red,'linestyle','-','linewidth',1); hold on

% aesthetics
set(gca,'box','off','tickdir','out','Xgrid','off','ygrid','off',...
    'xscale','log','xlim',[0.01,1],...
    'ylim',[0,ylimit],'linewidth',1.5,'fontsize',12);

ylabel('Spiking activity (norm.)');
lgn = legend('Dom. eye','Non-dom. eye','location','northwest');
set(lgn,'fontsize',10); legend boxoff


xtickdouble = [0.01,0.05,0.11,0.22,0.45,0.90];
xtickdoubletext =[0,0.05,0.11,0.22,0.45, 0.90];
xlabel([]); xticklabels(xtickdoubletext); xticks(xtickdouble);

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('V1_monoc_CRFs','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

% table for population CRF parameters
Rmax = [uCRF.DE.a(12,1);uCRF.NDE.a(12,1)];
K = [uCRF.DE.k(12,1);uCRF.NDE.k(12,1)];
n = [uCRF.DE.n(12,1);uCRF.NDE.n(12,1)];
rsquare = [uCRF.DE.rsquare(12,1);uCRF.NDE.rsquare(12,1)];
mean_params = table(Rmax,K,n,rsquare);

%% Parameter simulations

a = 1; %multiplicative response gain factor (=highest response amplitude)
k = 20;  %normalization pool (determines x position)
n = 2;   %exponent that determines rise and saturation
b = 0;    %baseline offset w/o stim
w = 0.85;

clear de* nrm* nrm_w* nde* jamovi*
for c=1:100
    %compute response for each conrast level c:  
    de(c) = a.* ((c.^n) ./ ((c.^n) + (k.^n)) ) + 0; 
      
    A1 = 1.5;
    A2 = 0.6;
    nde_A1(c) = A1.* ((c.^n) ./ ((c.^n) + (k.^n)) ) + 0; 
    nde_A2(c) = A2.* ((c.^n) ./ ((c.^n) + (k.^n)) ) + 0; 
    
    
    K1 = 1.5;
    K2 = 40;
    nde_K1(c) = a.* ((c.^n) ./ ((c.^n) + (K1.^n)) ) + 0; 
    nde_K2(c) = a.* ((c.^n) ./ ((c.^n) + (K2.^n)) ) + 0; 
    
    N1 = 2.5;
    N2 = 1;
    nde_N1(c) = a.* ((c.^N1) ./ ((c.^N1) + (k.^N1)) ) + 0; 
    nde_N2(c) = a.* ((c.^N2) ./ ((c.^N2) + (k.^N2)) ) + 0; 
    
    
end

figure('position',[542,551,268,138]);
semilogx(1:100,de,'k','linewidth',1.5); hold on
semilogx([1:100],nde_A2,'k','linestyle',':','linewidth',1.25)

ylim([0 1])
xlabel([]);
xticks([1,10,100]);
set(gca,'box','off','tickdir','out','fontsize',8,'linewidth',1);
xticklabels({'0','0.1','1'});
lgn = legend('Sim. DE','Sim. NDE (w)','location','northwest'); legend off
ylabel('Simulated response'); xlabel('Contrast');
axis square

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('SIM_rmax','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


figure('position',[542,551,268,138]);
semilogx(1:100,de,'k','linewidth',1.5); hold on
semilogx([1:100],nde_K2,'k','linestyle',':','linewidth',1.25)

ylim([0 1])
xlabel([]);
xticks([1,10,100]);
set(gca,'box','off','tickdir','out','fontsize',8,'linewidth',1);
xticklabels({'0','0.1','1'});
ylabel('Simulated response'); xlabel('Contrast');
axis square

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('SIM_C50','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

figure('position',[542,551,268,138]);
semilogx(1:100,de,'k','linewidth',1.5); hold on
semilogx([1:100],nde_N2,'k','linestyle',':','linewidth',1.25)

ylim([0 1])
xlabel([]);
xticks([1,10,100]);
set(gca,'box','off','tickdir','out','fontsize',8,'linewidth',1);
xticklabels({'0','0.1','1'});
lgn = legend('Sim. DE','Sim. NDE (w)','location','northwest'); legend off
ylabel('Simulated response'); xlabel('Contrast');
axis square

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('SIM_exponent','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Histogram distributions

if ~exist('PARAMS','var')
    [PARAMS] = getPARAMS_1D(UNIT, IDX, info, false,'norm');
end

if ~exist('NDE','var')
    NDE = fitNDE(UNIT, PARAMS, IDX, info,{'a','k','n','w'});
end

clear jamovi*

rsquares  = [NDE.a.rsquare;...
    NDE.k.rsquare;...
    NDE.n.rsquare];


for p = 1:3
    rsquares_sem(p,:) = std(rsquares(p,:),[],2,'omitnan') / sqrt(sum(~isnan(rsquares(p,:))));
    rsquares_std(p,:) = std(rsquares(p,:),[],2,'omitnan');

end
jamovi.rsquares1 = rsquares';

values = reshape(rsquares,[],1);
param_colors = [251,180,174;...
           179,205,227;...
           204,235,197]./255;
       
       pnames = {'Rmax','C50','n'};

clear G g
for i = 1:size(rsquares,1)
    g(i,:) = repmat(i,size(rsquares,2),1);
end
G = reshape(g,[],1);

close all;
figure('position',[495,578,508,109]);
nbins = 30;
mean_mark = 125;


for p = 1:3
 figure('position',[495,578,365,127]); 
h2 = errorbar(median(rsquares(p,:),'omitnan'),mean_mark,rsquares_sem(p).*2,'horizontal',...
    'MarkerSize',8,'MarkerEdgeColor',param_colors(p,:),'MarkerFaceColor',colors.black+0.1,...
    'color',param_colors(p,:),'linewidth',1); hold on
histogram(rsquares(p,:),nbins,'binWidth',0.02,'orientation','vertical',...
    'faceAlpha',1,'linewidth',1,'linestyle','none','faceColor',param_colors(p,:),'edgealpha',0.3); hold on

set(gca,'linewidth',1,'fontsize',12,'ylim',[0 125],'xlim',[0.5 1],'tickdir','out','box','off');
hl = hline(0); set(hl,'linestyle','-','linewidth',1,'color','k');
yticks([0:50:100]); xticks([0,0.25, 0.50, 0.75,1]);

if p == 1
h2.Marker = 'o';
elseif p == 2
    h2.Marker = 's';
elseif p == 3
    h2.Marker = '^';
end

set(gca, 'YGrid', 'on', 'XGrid', 'off');

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('rsquare_dist_',num2str(p),'.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

end

%% Distribution of w

close all
figure('position',[355,499,194,316]);
nbin = 15;

histogram(NDE.w.value,nbin,'binWidth',0.05,'faceAlpha',0.3,'linewidth',0.75,...
        'faceColor',colors.black+0.1,'edgecolor','k','edgealpha',0.8,'orientation','horizontal'); hold on
    
set(gca,'ylim',[0.1 1],'xlim',[0 150],'linewidth',1.5,'fontsize',10,'box','off');
ylabel('fitted weight (w)'); xlabel('# of units');

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('w_distribution','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% W x 1-OD
tw = 1;
figure;
hl = hline(0); hold on
set(hl,'color','k');
s =scatter(OCC.ocularity_abs,1-NDE.w.value','color','k'); hold on
set(gca,'ylim',[0,1],'xlim',[0 1],'linewidth',1,'fontsize',10);
xlabel('Ocular dominance'); ylabel('1 - fitted weight (w)')

x = OCC.ocularity_abs; y = 1-NDE.w.value';
mdl = fitlm(x,y);
CI = coefCI(mdl);

stats.WxOD.R2 = mdl.Rsquared.Adjusted;
stats.WxOD.t = mdl.Coefficients(2,3);
stats.WxOD.p = mdl.Coefficients(2,4);

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxWeight','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Simulating (w)


a = 1; %multiplicative response gain factor (=highest response amplitude)
k = 20;  %normalization pool (determines x position)
n = 2;   %exponent that determines rise and saturation
b = 0;    %baseline offset w/o stim
w = 0.85;

% simulate the dominant eye
for c=1:100
    %compute response for each conrast level c:  
    de(c) = a.* ((c.^n) ./ ((c.^n) + (k.^n)) ) + 0;
end

% simulate the non-dominant eye with (w)
figure('position',[339,808.3333333333333,331.3333333333333,287.3333333333333]);
semilogx(1:100,de,'k','linewidth',1.5); hold on

w = [0.5 0.6, 0.7, 0.8, 0.9];
for i = 1:length(w)
    for c=1:100
        nde_wr(c) = a.* (((w(i).*(c.^n))) ./ ((c.^n) + (k.^n)) ) + 0;
    end
    semilogx([1:100],nde_wr,'k','linestyle',':','linewidth',1.25)
end

ylim([0 1])
xlabel([]);
xticks([1,10,100]);
set(gca,'box','off','tickdir','out','fontsize',8,'linewidth',1);
xticklabels({'0','0.1','1'});
lgn = legend('Sim. DE','Sim. NDE (w)','location','northwest'); legend off
ylabel('Simulated response'); xlabel('Contrast');
axis square

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('SIM_w','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Statistics

jamovi.NDE_rsquares = rsquares';