%% Project OD. Figure 6. 
% DESCRIPTION: Performance of V1 binocular combination models with and
%   without the addition of OD information. 
% Compatible with ODproject_MUA workspace. 

% figure style
set(0,'DefaultFigureWindowStyle','normal') 
flagsave = 1;

% save directory
if flag_save == 1 
    USER = getenv('username');
    figDir = strcat('C:\Users\',USER,'\OneDrive - Vanderbilt\Data Analysis\Figures\OD Project\');
    cd(figDir);
    disp("Figure directory created");
end


%% Population level - 2D Surface plots - no OD 

mod = {'AVE','LSM','QDS','NRM'};

figure('position',[681,591,278,388]);
for m = 4 %1:length(mod) 

t = tiledlayout(2,1);
nexttile
h1 = plot(MODEL_BIN_noOCC.(mod{m}).pop.object.fit,[MODEL_BIN_noOCC.(mod{m}).pop.xData,MODEL_BIN_noOCC.(mod{m}).pop.yData],MODEL_BIN_noOCC.(mod{m}).pop.zData); hold on
set(gca,'zlim',[0.2,1.1]);

colorbar
colormap hot
h1(2).Marker = 'o';
h1(2).MarkerSize = 5;
h1(2).MarkerFaceColor = [1,1,1];
h1(2).MarkerEdgeColor = [0.2 0.2 0.2];
h1(2).LineWidth= 1;
view([-40.734001650968473,13.728494697691506]);
h1(1).LineStyle = 'none';
h1(1).FaceAlpha = 0.7;
t.Children(2).Projection = 'orthographic';
zlabel('Response'); xlabel([]); ylabel([]);
set(gca,'Clim',[0 1.1])

nexttile
h4 = plot(MODEL_BIN_noOCC.(mod{m}).pop.object.fit,[MODEL_BIN_noOCC.(mod{m}).pop.xData,MODEL_BIN_noOCC.(mod{m}).pop.yData],MODEL_BIN_noOCC.(mod{m}).pop.zData,'style','residual'); hold on
view([-40.734001650968473,13.728494697691506]);
t.Children(1).Projection = 'orthographic';
set(gca,'zlim',[-0.2,0.2]);
t.Children(1).Children(1).Marker = 'd';
t.Children(1).Children(1).MarkerFaceColor = [0.2 0.2 0.2];
t.Children(1).Children(1).MarkerEdgeColor = [1 1 1];
zlabel('Residual'); xlabel('DE cont.'); ylabel('NDE cont.');
grid off
end
if exist('figDir','var') 
    cd(figDir)
    exportgraphics(gcf,strcat('Model_fit_noOD',string(mod(m)),'.pdf'),'ContentType','vector')
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% 2D surface plot - With OD

mod = {'AVE','LSM','QDS','NRM'};

figure('position',[681,591,278,388]);
for m = 4 %1:length(mod)

t = tiledlayout(2,1);
nexttile
h1 = plot(MODEL_BIN_OCC.(mod{m}).pop.object.fit,[MODEL_BIN_OCC.(mod{m}).pop.xData,MODEL_BIN_OCC.(mod{m}).pop.yData],MODEL_BIN_OCC.(mod{m}).pop.zData); hold on
set(gca,'zlim',[0.2,1.1]);
map = [0.5 0.5 0.5];
colorbar 
colormap hot
h1(2).Marker = 'o';
h1(2).MarkerSize = 5;
h1(2).MarkerFaceColor = [1,1,1];
h1(2).MarkerEdgeColor = [0.2 0.2 0.2];
h1(2).LineWidth= 1;
view([-40.734001650968473,13.728494697691506]);
h1(1).LineStyle = 'none';
h1(1).FaceAlpha = 0.7;
t.Children(2).Projection = 'orthographic';
zlabel('Response'); xlabel([]); ylabel([]);
set(gca,'Clim',[0 1.2])

nexttile
h5 = plot(MODEL_BIN_OCC.(mod{m}).pop.object.fit,[MODEL_BIN_OCC.(mod{m}).pop.xData,MODEL_BIN_OCC.(mod{m}).pop.yData],MODEL_BIN_OCC.(mod{m}).pop.zData,'style','residual'); hold on
view([-40.734001650968473,13.728494697691506]);
t.Children(1).Projection = 'orthographic';
set(gca,'zlim',[-0.2,0.2]);
t.Children(1).Children(1).Marker = 'd';
t.Children(1).Children(1).MarkerFaceColor = [0.2 0.2 0.2];
t.Children(1).Children(1).MarkerEdgeColor = [1 1 1];
zlabel('Residual'); xlabel('DE cont.'); ylabel('NDE cont.');
grid off
end

if exist('figDir','var') 
    cd(figDir)
    exportgraphics(gcf,strcat('Model_fit_',string(mod(m)),'.pdf'),'ContentType','vector')
    disp("Figure saved");
else
    disp("Figure not saved");
end


%% V1 binocular responses - Contour plot

% plot3 Contour
x = flipud(info.cLevels(2:end));
y = info.cLevels(2:end);

[X,Y] = meshgrid(x,y);
close all
ct = 0;
clear c
windows = [12];
figure;
        

z = MODEL_BIN_noOCC.NRM.pop.zData;
Z = reshape(z,numel(z)/5,[]);
Z = Z;

[M,c] = contourf(X,Y,Z,':');
c.LineWidth = 0.2;
c.LineColor = [0 0 0];
axis square
colormap gray
colorbar

set(gca,'clim',[0 1],'TickDir','out','xtick',[0.1:0.2:0.9],'ytick',[0.1:0.2:0.9]);
set(gca,'xlim',[0.05,0.90],'ylim',[0.05,0.90]);
set(gca,'linewidth',1,'fontsize',10)
ylabel('DE Contrast'); xlabel('NDE Contrast');


if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('contourData','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Model contour prediction without ocularity 
figure('position',[144,673.6666666666666,825.6666666666666,233.3333333333334]);
ct = 0;

model_colors = [colors.blue+0.2;...
    colors.red;...
    colors.purple+0.2;...
    colors.green];

ft_models = MODEL_BIN_noOCC.labels;
for mod = 1:length(ft_models)
    
        ct = ct + 1;
        subplot(1,length(ft_models),ct)
        h = plot( MODEL_BIN_noOCC.(ft_models{mod}).pop.object.fit, [MODEL_BIN_noOCC.(ft_models{mod}).pop.xData,MODEL_BIN_noOCC.(ft_models{mod}).pop.yData],  MODEL_BIN_noOCC.(ft_models{mod}).pop.zData, 'Style', 'Contour');
        set(gca,'clim',[0 1.1],'TickDir','out','xtick',[0.1:0.2:0.9],'ytick',[0.1:0.2:0.9]);
        set(gca,'xlim',[0.05,0.90],'ylim',[0.05,0.90]);
        set(h(1),'LineStyle',':',...
            'LineWidth',0.2,...
            'LineColor',model_colors(mod,:),...
            'Fill','on');
        set(h(2),'Marker','none',...
            'MarkerEdgeColor',[1 1 1],...
            'LineWidth',0.1,...
            'LineStyle','none');
        colormap gray
        axis square
        grid off
        view([90 -90])
    
end

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('contourModels_noOCC','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Model fit with ocularity


figure('position',[144,673.6666666666666,825.6666666666666,233.3333333333334]);
ct = 0;

model_colors = [colors.blue+0.2;...
    colors.red;...
    colors.purple+0.2;...
    colors.green];

ft_models = MODEL_BIN_noOCC.labels;
for mod = 1:length(ft_models)
    
        ct = ct + 1;
        subplot(1,length(ft_models),ct)
        h = plot(MODEL_BIN_OCC.(ft_models{mod}).pop.object.fit, [MODEL_BIN_OCC.(ft_models{mod}).pop.xData,MODEL_BIN_OCC.(ft_models{mod}).pop.yData],  MODEL_BIN_OCC.(ft_models{mod}).pop.zData, 'Style', 'Contour');
        set(gca,'clim',[0 1.1],'TickDir','out','xtick',[0.1:0.2:0.9],'ytick',[0.1:0.2:0.9]);
        set(gca,'xlim',[0.05,0.90],'ylim',[0.05,0.90]);
        set(h(1),'LineStyle',':',...
            'LineWidth',0.5,...
            'LineColor',model_colors(mod,:),...
            'Fill','on');
        set(h(2),'Marker','none',...
            'MarkerEdgeColor',[1 1 1],...
            'LineWidth',0.4,...
            'LineStyle','none');
        colormap gray
        axis square
        grid off
        view([90 -90])
end

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('contourModels_occ','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Pull out Goodness of fit - R-squared
close all
model_colors = [colors.blue+0.2;...
    colors.red;...
    colors.purple+0.2;...
    colors.green];
model_colors2 = [colors.blue;...
    colors.dark_red;...
    colors.purple;...
    colors.dark_green];

ft_models = MODEL_BIN_noOCC.labels;
clear jamovi*
for m = 1:length(ft_models)
    jamovi{m}.rsquare_bin_noOCC = MODEL_BIN_noOCC.(ft_models{m}).unit.rsquare';
    jamovi{m}.rsquare_bin_OCC = MODEL_BIN_OCC.(ft_models{m}).unit.rsquare';
    jamovi{m}.rsquare_delta = (MODEL_BIN_OCC.(ft_models{m}).unit.rsquare' - MODEL_BIN_noOCC.(ft_models{m}).unit.rsquare') ./ (MODEL_BIN_noOCC.(ft_models{m}).unit.rsquare') .*100;
end

spacings = [1 2.5 4 5.5];

figure('position',[682.3333333333333,598.3333333333333,588.6666666666667,266.6666666666666]);

for m = 1:length(ft_models)
    al_goodplot(jamovi{m}.rsquare_bin_noOCC,spacings(m),0.5,model_colors(m,:),'left',[],[],0.2); hold on
    al_goodplot(jamovi{m}.rsquare_bin_OCC,spacings(m),0.5,model_colors2(m,:),'right',[],[],0.2); hold on
    hl = hline(mean(jamovi{m}.rsquare_bin_OCC)); set(hl,'color',model_colors(m,:),'linestyle',':','linewidth',1)
end
grid off
box off
xlabel('Model'); ylabel('Model performance (R-square)');
xticks([1,2.5,4,5.5])
xticklabels(ft_models);
set(gca,'ylim',[0 1],'xlim',[0,6.5])

if exist('figDir','var') && flagsave == 1
    cd(figDir);
    saveas(gcf, strcat('model_performances','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


%% Goodness of fit - AICc

clear jamovi
model_colors = [colors.blue+0.2;...
    colors.red;...
    colors.purple+0.2;...
    colors.green];
model_colors2 = [colors.blue;...
    colors.dark_red;...
    colors.purple;...
    colors.dark_green];

ft_models = MODEL_BIN_noOCC.labels;
spacings = [1 2 3 4];

for m = 1:length(ft_models)
    jamovi{m}.AIC_bin_noOCC = MODEL_BIN_noOCC.(ft_models{m}).unit.AICc';
    jamovi{m}.AIC_bin_OCC = MODEL_BIN_OCC.(ft_models{m}).unit.AICc';
    jamovi{m}.AIC_delta = (MODEL_BIN_noOCC.(ft_models{m}).unit.AICc' - MODEL_BIN_OCC.(ft_models{m}).unit.AICc') ./ (MODEL_BIN_OCC.(ft_models{m}).unit.AICc') .*100; 

end


figure('position',[682.3333333333333,598.3333333333333,588.6666666666667,331.3333333333334]);

for m = 1:length(ft_models)
    al_goodplot(jamovi{m}.AIC_bin_noOCC,spacings(m),0.5,model_colors(m,:),'left',[],[],0.2);
    al_goodplot(jamovi{m}.AIC_bin_OCC,spacings(m),0.5,model_colors2(m,:),'right',[],[],0.2);
end
grid off
box off
xlabel('Model'); ylabel('Model performance (AICc)');
xticks(1:4)
xticklabels(ft_models);
set(gca,'ylim',[-20 140],'xlim',[.5,4.5])
yticks(-20:20:140)

if exist('figDir','var') && flagsave == 1
    cd(figDir);
    saveas(gcf, strcat('model_performance_AICc','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Percent change in performance - AIC
ft_models = MODEL_BIN_noOCC.labels;
clear jamovi*
for m = 1:length(ft_models)
    jamovi{m}.AIC_delta = round((MODEL_BIN_noOCC.(ft_models{m}).unit.AICc' - MODEL_BIN_OCC.(ft_models{m}).unit.AICc') ./ (MODEL_BIN_OCC.(ft_models{m}).unit.AICc') .*100,2); 
end

format short 

% remove extreme data to contain the analysis around 0 +/- 150
for m = 1:length(ft_models)
jamovi{m}.AIC_delta(jamovi{m}.AIC_delta < -150) = 0;
jamovi{m}.AIC_delta(jamovi{m}.AIC_delta > 150) = 0;
end

for m = 1:4
    delta_means(m) = mean(jamovi{m}.AIC_delta,'omitnan');
    delta_median(m) = median(jamovi{m}.AIC_delta,'omitnan');
    delta_std(m) = std(jamovi{m}.AIC_delta,'omitnan');
    delta_sem(m) = std(jamovi{m}.AIC_delta,'omitnan') ./ sqrt(length(jamovi{m}.AIC_delta));
end

figure('position',[1000,918,219,323.6666666666665]);
b = bar(delta_means); hold on
errorbar(delta_means,delta_sem,'vertical','lineStyle','none','color',colors.black,'linewidth',2);
b.FaceColor = 'flat';
b.EdgeColor = 'flat';
for m = 1:4
    b.CData(m,:) = model_colors(m,:);
end
xticklabels({'AVG','SUM','QDS','NRM'});
xtickangle(45);
ylabel('Percent change in performance (AIC)');
box off
ylim([0 30])

if exist('figDir','var') && flagsave == 1
    cd(figDir);
    saveas(gcf, strcat('AIC_change','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

