%% S1. Supplemental figure 1, related to main figures 3 and 4. 
% Sample = 75 well isolated single neurons recorded from V1, across two
% animal subjects. This script is compatible with the workspace
% "ODproject_SUA". 


%% Initiate variables 
set(0,'DefaultFigureWindowStyle','normal') 
set(groot, 'DefaultAxesTickLabelInterpreter', 'none')
flag_save = 1;

% save directory
if flag_save == 1 
    USER = getenv('username');
    figDir = strcat('C:\Users\',USER,'\OneDrive - Vanderbilt\Data Analysis\Figures\OD Project\');
    cd(figDir);
    disp("Figure directory created");
end


% figure style
set(0,'DefaultFigureWindowStyle','normal') 
flagsave = 1;
flag_save = 1;


% save directory
if flagsave == 1 
    USER = getenv('username');
    figDir = strcat('C:\Users\',USER,'\OneDrive - Vanderbilt\Data Analysis\Figures\OD Project\');
    cd(figDir);
    disp("Figure directory created");
end

% Data split by monkey
clear J_units
for u = 1:length(IDX)
    J_units(u) = contains(string(IDX(u).penetration),'J');
end

clear J_units_idx B_units_idx
J_units_idx = find(J_units);
B_units_idx = find(~J_units);


clear UNIT_J UNIT_B IDX_J IDX_B
UNIT_J = UNIT(J_units_idx);
UNIT_B = UNIT(B_units_idx);
IDX_J = IDX(J_units_idx);
IDX_B = IDX(B_units_idx);


% Population by monkey
POP_J = getPOP(UNIT_J);
POP_B = getPOP(UNIT_B);
POP = getPOP(UNIT);

%% Single-unit ocular dominance histogram 

OCC   = getOCC(UNIT,[],IDX,[], info,3 ,'diUnitTuning');

figure('position',[355,499,194,316]);
nbin = 15;


histogram(OCC.ocularity(J_units),nbin,'binWidth',0.045,'faceAlpha',0.8,'linewidth',0.75,...
    'faceColor',colors.green,'edgecolor','none','edgealpha',0.5,'facealpha',0.5,'orientation','horizontal'); hold on % binsize 0.02 for orig figure

histogram(OCC.ocularity(~J_units).*-1,nbin,'binWidth',0.045,'faceAlpha',0.8,'linewidth',0.75,...
    'faceColor',colors.purple,'edgecolor','none','edgealpha',0.8,'facealpha',0.5,'orientation','horizontal'); hold on
    
set(gca,'ylim',[-1 1],'xlim',[0 5],'linewidth',1.5,'fontsize',10,'box','off');
ylabel('Ocular dominance'); xlabel('# of units');
xticks([0:1:5]);

if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ocular_dominance_histogram_single_units','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

% descriptive statistics
occ_stats.mean = mean(OCC.ocularity);
occ_stats.sd = std(OCC.ocularity);
occ_stats.kurtosis = kurtosis(OCC.ocularity);
occ_stats.skew = skewness(OCC.ocularity);

%% Binocular and summation asymmetry 

% select subject
subject = 'both';
tw = 12;

% Response matrices (6x6)
switch subject
    case 'J'
        POP = getPOP(UNIT_J);
        DATA = UNIT_J;   
    case 'B'
        POP = getPOP(UNIT_B);
        DATA = UNIT_B;
    case 'both'
        POP = getPOP(UNIT);
        DATA = UNIT;
end

% V1 response matrix 

% A1. Response matrices (5x5)

x = info.cLevels;
y = info.cLevels;

figure('position',[603,427,389.3333333333333,339]);

z = POP.DI.RESP_avg(:,tw);
Z = reshape(z,[],numel(z)/length(info.cLevels));
Z_flipped = flipud(Z);


imagesc(2:length(info.cLevels),2:length(info.cLevels),Z_flipped(1:5,2:end))
xticklabels({info.cLevels(2:end)}); xticks(2:length(info.cLevels))
yticklabels({fliplr(info.cLevels)}); yticks(2:length(info.cLevels))
ylabel({'Dom. Eye','Contrast'});
xlabel({'Non-Dom. Eye','Contrast'});
colormap hot
colorbar eastoutside
set(gca,'CLim',[0 inf]);
xtickangle(45); 
xlabel({'Non-Dom. Eye','Contrast'});
ylabel({'Dom. Eye','Contrast'});
axis square
       
if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('bin_response_matrix','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

% A2. Dichoptic response asymmetry 
contrast_num = length(info.cLevels);
figure('position',[603,427,389.3333333333333,339]);

orig_Z = Z_flipped;
orig_Z_flipped = rot90(orig_Z,2)';
response_asymmetry = orig_Z - orig_Z_flipped;

imagesc(2:contrast_num,2:contrast_num,response_asymmetry(1:5,2:end))
xticklabels({info.cLevels(2:end)}); xticks(2:contrast_num)
yticklabels({fliplr(info.cLevels)}); yticks(2:contrast_num)
ylabel({'Dom. Eye','Contrast'});
xlabel({'Non-Dom. Eye','Contrast'});
colormap jet
colorbar
set(gca,'clim',[-inf,inf])

axis square
xtickangle(45);

if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('resp_asymmetry','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% B. Binocular response summation 

close all
% calculate delta summation
clear summation* temp* nde* de*
for i = 1:contrast_num
    de = Z_flipped(i,1);
    for j = 1:contrast_num
        nde = Z_flipped(contrast_num,j);
        temp =  Z_flipped(i,j) / (de+nde); %binocular resp divided by sum of its monocular components
        summation(i,j) = temp;
    end
end

summation(:,1) = 0;
summation(contrast_num,:) = 0;


figure('position',[603,427,389.3333333333333,339]);

imagesc(2:contrast_num,2:contrast_num,summation(1:5,2:end))
xticklabels({info.cLevels(2:end)}); xticks(2:contrast_num)
yticklabels({fliplr(info.cLevels)}); yticks(2:contrast_num)
ylabel({'Dom. Eye','Contrast'});
xlabel({'Non-Dom. Eye','Contrast'});
colormap hot
colorbar
set(gca,'clim',[0,1])
xtickangle(45);
axis square

if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('summation_matrix','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


% B2. Binocular summation asymmetry
% calculate delta summation
for i = 1:contrast_num
    de = Z_flipped(i,1);
    for j = 1:contrast_num
        nde = Z_flipped(contrast_num,j);
        temp =  Z_flipped(i,j) / (de+nde); %binocular resp divided by sum of its monocular components
        summation(i,j) = temp;

    end
end

summation(:,1) = 0;
summation(contrast_num,:) = 0;
summation_flipped = rot90(summation,2)';
summation_asymmetry = summation - summation_flipped;

figure('position',[603,427,389.3333333333333,339]);
imagesc(2:contrast_num,2:contrast_num,summation_asymmetry(1:5,2:end))
xticklabels({info.cLevels(2:end)}); xticks(2:contrast_num)
yticklabels({fliplr(info.cLevels)}); yticks(2:contrast_num)
ylabel({'Dom. Eye','Contrast'});
xlabel({'Non-Dom. Eye','Contrast'});
colormap jet
colorbar
set(gca,'clim',[-.125,.125])

axis square
xtickangle(45);

xlabel({'Non-Dom. Eye','Contrast'});
ylabel({'Dom. Eye','Contrast'});


if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('summation_asymmetry_single','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end

%% Unit-by-unit Quantification - Both animals 

flag_single_cond = false;
contrast_num = length(info.cLevels);
ct = 0;

clear paired_response_sum* jamovi*
for unit = 1:1:size(POP.DI.resp,3)
    ct = ct + 1;

    z = squeeze(POP.DI.resp(:,tw,unit));

    if length(info.cLevels) == 5
        paired_response = [z(8),z(12);...
            z(9), z(17);...
            z(10), z(22);...
            z(14), z(18);...
            z(15), z(23);...
            z(20), z(24)];
    elseif length(info.cLevels) == 6
        paired_response = [z(9),z(14);...
            z(10), z(20);...
            z(11), z(26);...
            z(12), z(32);...
            z(16), z(21);...
            z(17), z(27);...
            z(18), z(33);...
            z(23), z(28);...
            z(24), z(34);...
            z(30), z(35)];
    end

    if flag_single_cond == true
        paired_response_delta = (paired_response(3,1) - paired_response(3,2)) ./ (paired_response(3,1)).*100;

    else
        paired_response_delta = (paired_response(:,1) - paired_response(:,2)) ./ (paired_response(:,1) + paired_response(:,2));
        paired_responses(:,ct) = paired_response_delta;
    end
    paired_response_sum.unit(ct) = sum(paired_response_delta,'all');
    paired_response_sum.unit(ct) = mean(paired_response_delta);

end

p = 95;
paired_response_sum.CI = CIFcn(paired_response_sum.unit,p);

% descriptives
paired_response_sum.avg = mean(paired_response_sum.unit);
paired_response_sum.med = median(paired_response_sum.unit);
paired_response_sum.sem = std(paired_response_sum.unit,[],1)./ sqrt(size(paired_response_sum.unit,1));
paired_response_sum.std = std(paired_response_sum.unit,[],1);

gtz = paired_response_sum.unit;
ltz = paired_response_sum.unit;
gtz(gtz<0) = nan;
ltz(gtz>0) = nan;

% Summation per unit
clear paired_summation_sum*
for unit = 1:size(POP.DI.resp,3)
    z = squeeze(POP.DI.resp(:,tw,unit));
    Z = reshape(z,[],numel(z)/length(info.cLevels));
    Z_flipped = flipud(Z);

    for i = 1:contrast_num
        de = Z_flipped(i,1);
        for j = 1:contrast_num
            nde = Z_flipped(contrast_num,j);
            temp =  Z_flipped(i,j) / (de+nde); %binocular resp divided by sum of its monocular components
            summation(i,j) = temp;

        end
    end
    summation(:,1) = 0;
    summation(contrast_num,:) = 0;
    summation_flipped = rot90(summation,2)';
    summation_asymmetry = summation - summation_flipped;
    temp = fliplr(summation_asymmetry);
    temp2 = temp(itriu(size(temp)));
    paired_summation_sum.unit(unit) = sum(temp2,'all');
    paired_summation_sum.unit(unit) = mean(temp2);
end

p = 95;
paired_summation_sum.CI = CIFcn(paired_summation_sum.unit,p);

% descriptives
paired_summation_sum.avg = mean(paired_summation_sum.unit);
paired_summation_sum.med = median(paired_summation_sum.unit);
paired_summation_sum.sem = std(paired_summation_sum.unit,[],1)./ sqrt(size(paired_summation_sum.unit,1));
paired_summation_sum.std = std(paired_summation_sum.unit,[],1);

jamovi.sum = paired_summation_sum.unit';
jamovi.resp = paired_response_sum.unit';
jamovi.zero = zeros(length(jamovi.sum),1);

%% Violin plots
close all

figure('position',[671,585,353.3333333333333,612]);
set(gca,'ylim',[-0.6 0.6],'xlim',[0,2])
h1 = hline(0); set(h1,'color','k','linestyle',':'); hold on
al_goodplot(paired_response_sum.unit,1,0.5,colors.blue,'bilateral',[],[],0.1);
grid off
box off
xlabel('Response'); ylabel('Asymmetry index');

if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('response_unit','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


figure('position',[671,585,353.3333333333333,612]);
set(gca,'ylim',[-.25 0.25],'xlim',[0,2])
h2 = hline(0); set(h2,'color','k','linestyle',':'); hold on
al_goodplot(paired_summation_sum.unit,1,0.5,colors.orange,'bilateral',[],[],0.1);
xlabel('Summation'); ylabel('Asymmetry index');
set(gca,'YAxisLocation','right')
box on
grid off

if exist('figDir','var') && flag_save == 1
    cd(figDir);
    saveas(gcf, strcat('summation_unit_single','.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
end


%% 
% Calculate ocular dominance
OCC   = getOCC(UNIT,[],IDX,[], info,3 ,'diUnitTuning'); % OD normalized to stimulus contrast 


if~exist('paired_response_sum','var')
    error('Asymmetry indices not yet calculated. Run F3 first');
end

clear sz rate
for u = 1:length(IDX)
sz(u) = sum(IDX(u).finalTrCnt);
rate(u) = IDX(u).rate;
end

% Ocular dominance x response asymmetry 

figure('position',[681,702,383,277]);
hl = hline(0); hold on
set(hl,'color','k');
s =scatter(OCC.ocularity_abs,paired_response_sum.unit',.05.*sz); hold on
set(gca,'ylim',[-0.6,0.6],'xlim',[0 1]);


clear mdl
 x = squeeze(OCC.ocularity_abs); y = paired_response_sum.unit';
 mdl = fitlm(x,y);
 stats.resp_asymmetry.r2 = mdl.Rsquared.Adjusted;
 stats.resp_asymmetry.t = mdl.Coefficients(2,3);
 stats.resp_asymmetry.p = mdl.Coefficients(2,4);
 
 h = plot(mdl);
 ylabel('Response asymmetry')
 xlabel('| Ocular dominance |');
 legend off
 axis square
 
 s(1).Marker = 'o';
 set(s,'MarkerFaceAlpha',0.3);

     h(1).Marker = 'o';
     s(1).MarkerFaceColor = colors.blue;
     s(1).MarkerEdgeColor = 'none';
     h(1).Color = 'none';

 if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxResponse_',string(tw),'.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
 end

 %% Ocular dominance x summation asymmetry 

for u = 1:length(IDX)
sz(u) = sum(IDX(u).finalTrCnt); % total number of trials across all conditions
rate(u) = IDX(u).rate;
end

figure('position',[681,702,383,277]);
hl = hline(0); hold on
set(hl,'color','k');
s =scatter(OCC.ocularity_abs,paired_summation_sum.unit',.05.*sz); hold on
set(gca,'ylim',[-0.3,0.3],'xlim',[0 1]);


clear mdl
 x = squeeze(OCC.ocularity_abs); y = paired_summation_sum.unit';
 mdl = fitlm(x,y);
 CI = coefCI(mdl);
 stats.sum_asymmetry.r2 = mdl.Rsquared.Adjusted;
 stats.sum_asymmetry.t = mdl.Coefficients(2,3);
 stats.sum_asymmetry.p = mdl.Coefficients(2,4);

 
 h = plot(mdl);
 ylabel('Summation Asymmetry')
 xlabel('| Ocular dominance |');
 legend off
 axis square
 
 s(1).Marker = 'o';
 set(s,'MarkerFaceAlpha',0.3);

 h(1).Marker = 'o';
 s(1).MarkerFaceColor = colors.orange;
 s(1).MarkerEdgeColor = 'none';


 h(1).Color = 'none';

 if exist('figDir','var') 
    cd(figDir);
    saveas(gcf, strcat('ODxSummation_',string(tw),'.svg'));
    disp("Figure saved");
else
    disp("Figure not saved");
 end

