%% S2. Supplemental figure 2, related to main figure 5.
% DESCRIPTION: Descriptives for monocular CRF parameters. 
% This script is compatible with the workspace
% "ODproject_MUA_workspace.m". 


%% Parameter distributions for each eye
eye = {'DE','NDE'};
param = {'a','k','n'};

clear params*

params.DE.value  = [PARAMS.DE.a;...
    PARAMS.DE.k;...
    PARAMS.DE.n];

params.NDE.value = [PARAMS.NDE.a;...
    PARAMS.NDE.k;...
    PARAMS.NDE.n];

for p = 1:length(param)
    params.DE.sem(p,:) = std(params.DE.value(p,:),[],2,'omitnan') / sqrt(sum(~isnan(params.DE.value(p,:))));
    params.DE.std(p,:) = std(params.DE.value(p,:),[],2,'omitnan');
    params.NDE.sem(p,:) = std(params.NDE.value(p,:),[],2,'omitnan') / sqrt(sum(~isnan(params.NDE.value(p,:))));
    params.NDE.std(p,:) = std(params.NDE.value(p,:),[],2,'omitnan');
end

clear jamovi
jamovi.DE_params = params.DE.value';
jamovi.NDE_params = params.NDE.value';

DE_values = reshape(params.DE.value,[],1);
NDE_values = reshape(params.NDE.value,[],1);
param_colors = [251,180,174;...
           179,205,227;...
           204,235,197]./255;
       
       pnames = {'Rmax','C50','n'};

close all
nbins = [5,30,30];
barwidths = [0.05, 0.020, 0.08];
mean_mark = 50;

for e = 1:length(eye)
    for p = 1:length(param)
        figure('position',[495,578,365,127]);

        histogram(params.(eye{e}).value(p,:),nbins(p),'binWidth',barwidths(p),'orientation','vertical',...
            'faceAlpha',1,'linewidth',1,'linestyle','none','faceColor',param_colors(p,:),'edgealpha',0.3); hold on
        if p == 1
            mean_mark = 60;
        elseif p == 2
            mean_mark = 80;
        elseif p == 3
            mean_mark = 60;
        end
        h2 = errorbar(mean(params.(eye{e}).value(p,:),'omitnan'),mean_mark,params.(eye{e}).std(p),'horizontal',...
            'MarkerSize',8,'MarkerEdgeColor',param_colors(p,:),'MarkerFaceColor',colors.black+0.1,...
            'color',param_colors(p,:),'linewidth',1); hold on
        set(gca,'linewidth',1,'fontsize',12,'ylim',[0 125],'xlim',[0.4 1],'tickdir','out','box','off');

        if p == 1
            h2.Marker = 'o';
            set(gca,'ylim',[-0.5 60],'xlim',[0 3]);
            xticks([0,0.50, 1, 1.5, 2.0, 2.5,3]); yticks([0:20:60]);
        elseif p == 2
            h2.Marker = 's';
            set(gca,'ylim',[-0.5 80],'xlim',[0 1]);
            xticks([0,0.20, 0.40,0.60,0.80, 1]); yticks([0:20:80]);
        elseif p == 3
            h2.Marker = '^';
            set(gca,'ylim',[-0.5 60],'xlim',[0 7.1]);
            xticks([0,1,2,3,4,5,6,7]);
        end

        set(gca, 'YGrid', 'on', 'XGrid', 'off');

        if exist('figDir','var')
            cd(figDir);
            saveas(gcf, strcat('param_dist_',eye{e},'_',num2str(p),'.svg'));
            disp("Figure saved");
        else
            disp("Figure not saved");
        end

    end
end

%% Goodness of fit distributions for each eye 

clear rsquares*
rsquares.DE.value = PARAMS.DE.rsquare;
rsquares.NDE.value = PARAMS.NDE.rsquare;

rsquares.DE.value(rsquares.DE.value <= 0) = nan;
rsquares.NDE.value(rsquares.NDE.value <= 0) = nan;

eye = {'DE','NDE'};

for e = 1:length(eye)

    rsquares.(eye{e}).sem = std(rsquares.(eye{e}).value,[],2,'omitnan') / sqrt(sum(~isnan(rsquares.(eye{e}).value)));
    rsquares.(eye{e}).std = std(rsquares.(eye{e}).value,[],2,'omitnan');

end
close all
for e = 1:length(eye)
 
        figure('position',[495,578,365,127]);
        
        histogram(rsquares.(eye{e}).value,25,'binWidth', 0.005,'orientation','vertical',...
            'faceAlpha',1,'linewidth',1,'linestyle','none','faceColor',colors.black,'edgealpha',0.3); hold on
        mean_mark = 100;
        h2 = errorbar(median(rsquares.(eye{e}).value,'omitnan'),mean_mark,rsquares.(eye{e}).sem.*2,'horizontal',...
            'MarkerSize',8,'MarkerEdgeColor',colors.black,'MarkerFaceColor',colors.black+0.1,...
            'color',colors.black,'linewidth',1); hold on
        set(gca,'linewidth',1,'fontsize',12,'ylim',[0 100],'xlim',[0.8 1],'tickdir','out','box','off');
        hl = hline(0); set(hl,'linestyle','-','linewidth',1,'color','k');
         
        set(gca, 'YGrid', 'on', 'XGrid', 'off');
        h2.Marker = 'diamond';

        if exist('figDir','var')
            cd(figDir);
            saveas(gcf, strcat('rsquares_',eye{e},'.svg'));
            disp("Figure saved");
        else
            disp("Figure not saved");
        end

    
end