function [uCRF] = fitMeanCRF(UNIT,IDX,info, dataform)
%CRFparams.m. Measure CRFs for UNIT structure.
%   UNIT is the structure with the data, flag_individualplots for visualization
condition = upper({'de','nde','bin'});
flag = 0;
clear resp* pop*


% Retrieve responses from UNIT
for uct = 1:length(UNIT)
    unit.BIN(:,:,uct) = UNIT(uct).BIN.RESP_avg(:,[1:info.windows-1]) - UNIT(uct).BIN.RESP_avg(:,end);
    unit.DE(:,:,uct) = UNIT(uct).DE.RESP_avg(:,[1:info.windows-1]) - UNIT(uct).DE.RESP_avg(:,end);
    unit.NDE(:,:,uct) = UNIT(uct).NDE.RESP_avg(:,[1:info.windows-1]) - UNIT(uct).NDE.RESP_avg(:,end);
end

unit.DE(unit.DE < 0) = 0;
unit.NDE(unit.NDE < 0) = 0;
unit.BIN(unit.BIN < 0) = 0;

% central tendency (mean)
pop.BIN.resp = nanmean(unit.BIN,3); pop.BIN.resp(1,:) =0;
pop.BIN.sem = nanstd(unit.BIN,[],3) ./ sqrt(size(unit.BIN,3));
pop.DE.resp = nanmean(unit.DE,3); pop.DE.resp(1,:) =0;
pop.DE.sem = nanstd(unit.DE,[],3) ./ sqrt(size(unit.DE,3));
pop.NDE.resp = nanmean(unit.NDE,3); pop.NDE.resp(1,:) =0;
pop.NDE.sem = nanstd(unit.NDE,[],3) ./ sqrt(size(unit.NDE,3));

% get 95% CI
for cond = 1:length(condition)
    for tw = 1:info.windows-1
        for c = 1:size(unit.(condition{cond}),1)
            pop.(condition{cond}).CI(c,tw,:) = CI95(unit.(condition{cond})(c,tw,:));
        end
    end
end

if size(IDX(uct).cLevels) > 1
    contrast = IDX(uct).cLevels(:,2);
else
    contrast = IDX(uct).cLevels';
end
contrast(1) = 0.01;
    
for tw = 1:info.windows-1  % for all but the bsl window
    
    if flag == 1
        break
    end
    
    for cond = 1:length(condition)
        
        
        if flag == 1
            break
        end
        
        % note, average response is mean
        
        try
            resp.mean = pop.(condition{cond}).resp(:,tw);
            resp.max = max(pop.(condition{cond}).resp(:,tw),[],'all');
            resp.lower = pop.(condition{cond}).CI(:,tw,1);
            resp.upper = pop.(condition{cond}).CI(:,tw,2);
        catch
            flag = 1;
            warning('Could not retrieve datapoints');
            break
        end
        
        if cond == 1 %DE
            B = resp.mean(1);
        end
        
%         if bslc == true
%             resp.mean = resp.mean - B;
%             resp.max = resp.max - B;
%             resp.lower = resp.lower - B;
%             resp.upper = resp.upper - B;
%         end
        
        % Define function
        fop = fitoptions('Method','NonlinearLeastSquares');
        fcn = @(a,k,n,x) ((a.*(x.^n)) ./ ((x.^n) + (k.^n))) + 0; % B = DE baseline
        switch dataform
            case 'norm'
                
                %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %                [ a (rmax)                K  n] %
                fop.Upper      = [         resp.max(end)   .80  5];%
                fop.Lower      = [                 0       .05  1];%
                fop.StartPoint = [1.1*resp.mean(end)    .40  2];%
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                
            otherwise
                
                %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %                [ a (rmax)                K  n] %
                fop.Upper      = [         resp.max(end) .80  5];%
                fop.Lower      = [                    1  .05  1];%
                fop.StartPoint = [1.1*resp.mean(end)  .40  2];%
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        end
        
        curves = {'mean','lower','upper'};
        
        for j = 1:length(curves)
            
            % fit
            try
                [f, gof] = fit(contrast,resp.(curves{j}),fcn,fop);
            catch
                warning('Failed to fit data')
                %flag = 1;
                break
            end
            
            x = 0.01:.01:1;
            uCRF.(condition{cond}).fitobject(tw,j).f = f;
            uCRF.(condition{cond}).a(tw,j) = f.a;
            uCRF.(condition{cond}).k(tw,j) = f.k;
            uCRF.(condition{cond}).n(tw,j) = f.n;
            uCRF.(condition{cond}).rsquare(tw,j) = gof.rsquare;
            uCRF.(condition{cond}).gof(tw,j) = gof;
            uCRF.(condition{cond}).data(:,tw,j) = resp.(curves{j});
           
            uCRF.(condition{cond}).curve(:,tw,j) = feval(f,x);
            
            
        end
        
             uCRF.(condition{cond}).sem(:,tw) = pop.(condition{cond}).sem(:,tw);
    end
    
    if flag == 1
        break
    end
    
    uCRF.B(tw) = B;
end


end

