function [MODEL] = fitModel_fullTW(UNIT,IDX,info,flag_weights,flag_ocularity,binocular_only,NDE, ASY)
%CRFparams.m. Measure CRFs for UNIT structure.
%   UNIT is the structure with the data, flag_individualplots for visualization

if binocular_only == true
    contrast_idx = [8:12,14:18,20:24,26:30,32:36]; % only binocular conditions
else
    contrast_idx = 1:length(info.diLevels); % all conditions
end

for u = 1:length(UNIT)

    flag = 0;
    x = IDX(u).diLevels(contrast_idx,1); x(x == 0) = 0.01; % DE only if contains 0
    y = IDX(u).diLevels(contrast_idx,2); y(y == 0) = 0.01; % NDE only if contains 0

    if flag_ocularity == true
        if nargin > 7
            w = 1-(3.*ASY.unit(u)); % dichoptic response asymmetry 
        elseif nargin > 6
            w = NDE.w.value(u); % full time window (12)
            %w = 1+rand(1);
        
        else
            w = 1-abs(IDX(u).X.occ(1));
        end

    else
        w = 1;
    end

    
    tw = info.windows-1; % full time window       
    
    w_placement = 'contrast_numerator';
    [labels, mod] = getModels(w_placement);

        if flag == 1
            break
        end

        % note, average response is mean
        z = cellfun(@(x) mean(x(tw,:)), UNIT(u).DI.RESP_trls(contrast_idx))';
        weights = cellfun(@(x) size(x,2), UNIT(u).DI.RESP_trls(contrast_idx));
        try
            z_max = cellfun(@(x) max(x(tw,:)), UNIT(u).DI.RESP_trls(contrast_idx))';
        catch
            flag = 1;
            warning('Could not perform matrix-wise calculation. Unit %d was not fit',u)
            continue
        end


        B = z(1);
        
        for m = 1:length(labels)

        %ft = fittype( string(mod.(labels{m})), 'independent', {'x', 'y'}, 'dependent', 'z' );
        ft = fittype( string(mod{1,m}), 'problem','w','independent', {'x', 'y'}, 'dependent', 'z');
        opts = fitoptions( 'Method', 'NonlinearLeastSquares' );
        opts.Display = 'Off';

        %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %                 [    a (rmax)     K   n] %
        opts.StartPoint = [    0.5         .20  1];%
        opts.Upper      = [    max(z_max)  .50  3];%
        opts.Lower      = [    .01         .1  0.5];%

        if flag_weights == true
            opts.weights = [weights];
        else
            opts.weights = [];
        end
        % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        [xData, yData, zData] = prepareSurfaceData( x, y, z );
        % fit
        try
            [fitresult, gof, output] = fit([xData,yData],zData,ft,opts,'problem',w);
        catch
            flag = 1;
            warning('Could not use fit(). Unit %d was not fit',u)
            break
        end

        if flag == 1
            break
        end

        try
        MODEL.(labels{m}).unit.object(u).fitobject = output;
        MODEL.(labels{m}).unit.object(u).fit = fitresult;
        MODEL.(labels{m}).unit.gof(u) = gof;
        MODEL.(labels{m}).unit.yData(:,u) = yData;
        MODEL.(labels{m}).unit.xData(:,u) = xData;
        MODEL.(labels{m}).unit.zData(:,u) = zData;
        MODEL.(labels{m}).unit.a(u) = fitresult.a;
        MODEL.(labels{m}).unit.k(u) = fitresult.k;
        MODEL.(labels{m}).unit.n(u) = fitresult.n;
        MODEL.(labels{m}).unit.rsquare(u) = gof.adjrsquare;
        MODEL.(labels{m}).unit.B(u) = B;

        % Calculating AIC
        SSE = gof.sse;
        n = output.numobs;
        k = output.numparam;

        AICc = n*log(SSE / n) + 2*k + ((2*k*(k+1)) / (n - k - 1)) + n*log(2*pi)+n;

        MODEL.(labels{m}).unit.AICc(u) = AICc;
        catch
             break
             flag = 1;
         end

        end

    z_all(:,u) = UNIT(u).DI.RESP_avg(contrast_idx,tw);
    w_all(u) = w;
    weights_all(:,u) = weights;

end

MODEL.mod = mod;
MODEL.labels = labels;
MODEL.ocularity = flag_ocularity;
MODEL.weights = flag_weights;

%% Population of units
% Fit Population 
z_avg = nanmean(z_all,2); 

if flag_ocularity == true

    w = mean(w_all);
else
    w = 1;
end
%x = IDX(1).diLevels(:,1); x(x == 0) = 0.01;
%y = IDX(1).diLevels(:,2); y(y == 0) = 0.01;
weights = mean(weights_all,2);

clear z 

    z = z_avg;

    for m = 1:length(labels)

        [xData, yData, zData] = prepareSurfaceData( x, y, z );
        ft = fittype( string(mod{1,m}), 'problem','w','independent', {'x', 'y'}, 'dependent', 'z' );
        opts.Upper      = [    max(z)*2  .50  3];%

        if flag_weights == true
            opts.weights = [weights];
        else
            opts.weights = [];
        end
        
        % fit
        try
            [fitresult, gof,output] = fit([xData,yData],zData,ft,opts,'problem',w);
       catch
            warning('Could not use fit(). Unit %d was not fit',u)
            flag = 1;
            break
        end
        MODEL.(labels{m}).pop.object.fitobject = output;
        MODEL.(labels{m}).pop.object.fit = fitresult;
        MODEL.(labels{m}).pop.gof = gof;
        MODEL.(labels{m}).pop.yData = yData;
        MODEL.(labels{m}).pop.xData = xData;
        MODEL.(labels{m}).pop.zData = zData;
        MODEL.(labels{m}).pop.a = fitresult.a;
        MODEL.(labels{m}).pop.k = fitresult.k;
        MODEL.(labels{m}).pop.n = fitresult.n;
        MODEL.(labels{m}).pop.rsquare = gof.adjrsquare;


        % Calculating AIC
        SSE = gof.sse;
        n = output.numobs;
        k = output.numparam;

        AICc = n*log(SSE / n) + 2*k + ((2*k*(k+1)) / (n - k - 1)) + n*log(2*pi)+n;

        MODEL.(labels{m}).pop.AICc = AICc;
    end


end

