function [NDE] = fitNDE(UNIT, PARAMS, IDX, info, param)
% NDEfit.m. Refit NDE with some fixed parameters
%   UNIT is the structure with the data.

if isempty(param)
param = {'a','k','n','w','ww'};
end

x = 0.01:.01:1;

for uct = 1:length(UNIT)
    contrast = IDX(uct).cLevels'; contrast(1) = 0.01;
    
    
    for tw = 1:info.windows-1
        
    
        % Grab parameters from the DE
        A = PARAMS.DE.a(tw,uct); K = PARAMS.DE.k(tw,uct); N = PARAMS.DE.n(tw,uct);
        B = PARAMS.B(tw,uct);
        
        % Collect NDE responses
        average_resp = cellfun(@(x) mean(x(tw,:)), UNIT(uct).NDE.RESP_trls)';
        max_resp = cellfun(@(x) max(x(tw,:)), UNIT(uct).NDE.RESP_trls)';
        
        if any(isnan(average_resp),'all') 
            warning('Response vector contained nan. Unit %d was not fit',uct)
            break
        end
        
        if any(average_resp<-0.5,'all') 
            average_resp(average_resp < 0) = 0; %rectify
        end

        
        for p = 1:length(param)
            switch param{p}
                case 'a'
                    fop = fitoptions('Method','NonlinearLeastSquares');
                    fcn = @(a,x) ((a.*(x.^N)) ./ ((x.^N) + (K.^N))) + B; % a free to vary
                    %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                [ a                     %
                    fop.Upper      = [ max_resp(end)*2      ];            %max_resp(end)*2
                    fop.Lower      = [ 0                    ];%
                    fop.StartPoint = [ A                     ];%
                    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    
                    [f, gof] = fit(contrast,average_resp,fcn,fop);
                    value = f.a;
                    
                case 'k'
                    fop = fitoptions('Method','NonlinearLeastSquares');
                    fcn = @(k,x) ((A.*(x.^N)) ./ ((x.^N) + (k.^N))) + B; % k free to vary
                    %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                [ k                     %
                    fop.Upper      = [ .30                  ];%
                    fop.Lower      = [ .01                   ];%
                    fop.StartPoint = [ K                     ];%
                    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    
                    [f, gof] = fit(contrast,average_resp,fcn,fop);
                    value = f.k;
                    
                case 'n'
                    fop = fitoptions('Method','NonlinearLeastSquares');
                    fcn = @(n,x) ((A.*(x.^n)) ./ ((x.^n) + (K.^n))) + B; % n free to vary
                    %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                [ n                     %
                    fop.Upper      = [ N+(N*.25)             ];%
                    fop.Lower      = [ 0                    ];%
                    fop.StartPoint = [ N                     ];%
                    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    
                    [f, gof] = fit(contrast,average_resp,fcn,fop);
                    value = f.n;
                    
                case 'w'
                    
                    fop = fitoptions('Method','NonlinearLeastSquares');
                    %fcn = @(w,x) A.*((w.*(x.^N)) ./ ((x.^N) + (K.^N)) ) + B;
                    fcn = @(w,x) ((A.*(w.*x.^N)) ./ ((x.^N) + (K.^N))) + B; % B = DE baseline
                    %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                [ w                     %
                    fop.Upper      = [ 1                    ];%
                    fop.Lower      = [ 0                    ];%
                    fop.StartPoint = [ 0.01                 ];%
                    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

                    [f, gof] = fit(contrast,average_resp,fcn,fop);
                    value = f.w;
                        

                    
                case 'ww'
                    fop = fitoptions('Method','NonlinearLeastSquares');
                    %fcn = @(w,x) A.*((w.*(x.^N)) ./ ((x.^N) + (K.^N)) ) + B;
                    fcn = @(w,x) ((A.*(w.*x.^N)) ./ ((w.*x.^N) + (K.^N))) + B; % B = DE baseline
                    %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                [ w                     %
                    fop.Upper      = [ 1                     ];%
                    fop.Lower      = [ 0                     ];%
                    fop.StartPoint = [ 0.01                     ];%
                    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    
                    [f, gof] = fit(contrast,average_resp,fcn,fop);
                    value = f.w;
                    
                    %             case 'ne'
                    %                 fop = fitoptions('Method','NonlinearLeastSquares');
                    %                 fcn = @(ne,x) A.*((x.^ne) ./ ((x.^N) + (K.^N)) ) + B; % n free to vary
                    %                 %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                 %                [ n                     %
                    %                 fop.Upper      = [ N+(N*0.20)            ];%
                    %                 fop.Lower      = [ 0.5                   ];%
                    %                 fop.StartPoint = [ N                     ];%
                    %                 % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    %
                    %                 [f, gof] = fit(contrast,average_resp,fcn,fop);
                    %                 value = f.ne;
                    %
                    %             case 'wm'
                    %                 fop = fitoptions('Method','NonlinearLeastSquares');
                    %                 fcn = @(wm,x) A.*((wm.*(x.^N)) ./ ((x.^N) + (K.^N)) ) + B;
                    %                 %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                 %                [ w                     %
                    %                 fop.Upper      = [ 2                     ];%
                    %                 fop.Lower      = [ 0.5                   ];%
                    %                 fop.StartPoint = [ 0.5                   ];%
                    %                 % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    %
                    %                 [f, gof] = fit(contrast,average_resp,fcn,fop);
                    %                 value = f.wm;
                    %
                    %             case 'we_ne'
                    %                 fop = fitoptions('Method','NonlinearLeastSquares');
                    %                 fcn = @(we,ne,x) A.*(((we.*x).^ne) ./ ((x.^N) + (K.^N)) ) + B; % B = DE baseline
                    %                 %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                 %                [ we      ne               %
                    %                 fop.Upper      = [ 2       5              ];%
                    %                 fop.Lower      = [ 0.01   0.5             ];%
                    %                 fop.StartPoint = [ 0.01     N             ];%
                    %                 % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    %
                    %                 [f, gof] = fit(contrast,average_resp,fcn,fop);
                    %                 value = f.we;
                    %                 value2 = f.ne;
                    %
                    %             case 'we_wd'
                    %                 fop = fitoptions('Method','NonlinearLeastSquares');
                    %                 fcn = @(we,wd,x) A.*((we.*(x.^N)) ./ ((wd.*(x.^N)) + (K.^N)) ) + B; % B = DE baseline
                    %                 %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                 %                [ we      wd              %
                    %                 fop.Upper      = [ 2       10             ];%
                    %                 fop.Lower      = [ 0.01   1               ];%
                    %                 fop.StartPoint = [ 0.01   1              ];%
                    %                 % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    %
                    %                 [f, gof] = fit(contrast,average_resp,fcn,fop);
                    %                 value = f.we;
                    %                 value2 = f.wd;
                    %
                    %             case 'ne_nd'
                    %                 fop = fitoptions('Method','NonlinearLeastSquares');
                    %                 fcn = @(ne,nd,x) A.*(((x.^ne)) ./ (((x.^nd)) + (K.^N)) ) + B; % B = DE baseline
                    %                 %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%
                    %                 %                [ ne         nd            %
                    %                 fop.Upper      = [ N+(N*0.20) N+(N*0.20)  ];%
                    %                 fop.Lower      = [ 0.5        0.5         ];%
                    %                 fop.StartPoint = [ 1          1           ];%
                    %                 % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                    %
                    %                 [f, gof] = fit(contrast,average_resp,fcn,fop);
                    %                 value = f.ne;
                    %                 value2 = f.nd;
                    
            end
            
            NDE.(param{p}).fitobject(tw,uct).f = f;
            NDE.(param{p}).curve(:,tw,uct) = feval(f,[0.01:0.01:1])-B';
            NDE.(param{p}).value(tw,uct) = value;
            
            if p > 6
                NDE.(param{p}).value2(tw,uct) = value2;
            end
            
            gof.rsquare(gof.rsquare < 0) = 0;
            NDE.(param{p}).rsquare(tw,uct) = gof.rsquare;
            NDE.(param{p}).gof(tw,uct) = gof;
            
        end
    end
    
end

for p = 1:length(param)
    for tw = 1:info.windows-1
        P = 95;
        NDE.(param{p}).rsquare_avg(tw,:) = mean(NDE.(param{p}).rsquare(tw,:));
        NDE.(param{p}).rsquare_median(tw,:) = median(NDE.(param{p}).rsquare(tw,:));
        NDE.(param{p}).rsquare_CI(tw,:) = CIFcn(NDE.(param{p}).rsquare(tw,:),P);
    end
end

% Calculate average curves and 95% CI
for tw = 1:info.windows-1
    for p = 1:length(param)
        A = mean(PARAMS.DE.a(tw,:),2);
        Ac = CI95(PARAMS.DE.a(tw,:));
        
        K = mean(PARAMS.DE.k(tw,:),2);
        Kc = CI95(PARAMS.DE.k(tw,:));
        
        N = mean(PARAMS.DE.n(tw,:),2);
        Nc = CI95(PARAMS.DE.n(tw,:));
        
        value = mean(NDE.(param{p}).value(tw,:),2);
        value_c = CI95(NDE.(param{p}).value(tw,:));
        
        B = 0;
        
        switch param{p}
            case 'a'
                A = value;
                Ac = value_c;
                NDE.(param{p}).curve_avg(:,tw) = ((A.*(x.^N)) ./ ((x.^N) + (K.^N))) + B;
                NDE.(param{p}).curve_upper(:,tw) = ((Ac(2).*(x.^Nc(2))) ./ ((x.^Nc(2)) + (Kc(1).^Nc(2)))) + B;
                NDE.(param{p}).curve_lower(:,tw) = ((Ac(1).*(x.^Nc(1))) ./ ((x.^Nc(1)) + (Kc(2).^Nc(1)))) + B;
               
            case 'k'
                K = value;
                Kc = value_c;
                NDE.(param{p}).curve_avg(:,tw) = ((A.*(x.^N)) ./ ((x.^N) + (K.^N))) + B;
                NDE.(param{p}).curve_upper(:,tw) = ((Ac(2).*(x.^Nc(2))) ./ ((x.^Nc(2)) + (Kc(1).^Nc(2)))) + B;
                NDE.(param{p}).curve_lower(:,tw) = ((Ac(1).*(x.^Nc(1))) ./ ((x.^Nc(1)) + (Kc(2).^Nc(1)))) + B;
            
            case 'n'
                N = value;
                Nc = value_c;
                NDE.(param{p}).curve_avg(:,tw) = ((A.*(x.^N)) ./ ((x.^N) + (K.^N))) + B;
                NDE.(param{p}).curve_upper(:,tw) = ((Ac(2).*(x.^Nc(2))) ./ ((x.^Nc(2)) + (Kc(1).^Nc(2)))) + B;
                NDE.(param{p}).curve_lower(:,tw) = ((Ac(1).*(x.^Nc(1))) ./ ((x.^Nc(1)) + (Kc(2).^Nc(1)))) + B;
                
            case 'w'
                W = value;
                Wc = value_c;
                NDE.(param{p}).curve_avg(:,tw) = ((A.*(W.*x.^N)) ./ ((x.^N) + (K.^N))) + B;
                NDE.(param{p}).curve_upper(:,tw) = ((Ac(2).*(Wc(2).*x.^Nc(2))) ./ ((x.^Nc(2)) + (Kc(1).^Nc(2)))) + B;
                NDE.(param{p}).curve_lower(:,tw) = ((Ac(1).*(Wc(1).*x.^Nc(1)))  ./ ((x.^Nc(1)) + (Kc(2).^Nc(1)))) + B;
                
            case 'ww'
                W = value;
                Wc = value_c;
                NDE.(param{p}).curve_avg(:,tw) = ((A.*(W.*x.^N)) ./ ((W.*x.^N) + (K.^N))) + B;
                NDE.(param{p}).curve_upper(:,tw) = ((Ac(2).*(Wc(2).*x.^Nc(2))) ./ ((Wc(2).*x.^Nc(2)) + (Kc(1).^Nc(2)))) + B;
                NDE.(param{p}).curve_lower(:,tw) = ((Ac(1).*(Wc(1).*x.^Nc(1)))  ./ ((Wc(1).*x.^Nc(1)) + (Kc(2).^Nc(1)))) + B;
                
        end
    end
    
end