function [PARAMS] = getPARAMS_1D_fullTW(UNIT,IDX,info, bslc, dataform)
%CRFparams.m. Measure CRFs for UNIT structure.
%   UNIT is the structure with the data, flag_individualplots for visualization
condition = upper({'de','nde'});

PARAMS.B = zeros(1,length(UNIT));

for u = 1:length(UNIT)

    flag = 0;
    if size(IDX(u).cLevels) > 1
        contrast = IDX(u).cLevels(:,2);
    else
        contrast = IDX(u).cLevels';
    end
    contrast(1) = 0.01;



    if flag == 1
        continue
    end

    for cond = 1:length(condition)


        if flag == 1
            break
        end
        tw = info.windows-1;
        % note, average response is mean
        average_resp = cellfun(@(x) mean(x(tw,:)), UNIT(u).(condition{cond}).RESP_trls)';
        try
            max_resp = cellfun(@(x) max(x(tw,:)), UNIT(u).(condition{cond}).RESP_trls)';
        catch
            flag = 1;
            warning('Could not perform matrix-wise calculation. Unit %d was not fit',u)
            break
        end

        if any(isnan(average_resp),'all')
            warning('Response vector contained nan. Unit %d was not fit',u)
            break
        end

        if any(average_resp<-0.5,'all')
            average_resp(average_resp < 0) = 0; %rectify
        end

        if cond == 1 %DE
            B = average_resp(1);
        end

        if bslc == true
            average_resp = average_resp - B;
            max_resp = max_resp - B;
        end

        fop = fitoptions('Method','NonlinearLeastSquares');
        fcn = @(a,k,n,x) ((a.*(x.^n)) ./ ((x.^n) + (k.^n))) + B; % B = DE baseline

        switch dataform
            case 'norm'

                %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %                [ a (rmax)                K  n] %
                fop.Upper      = [         max_resp(end)   1  10];%
                fop.Lower      = [             0.01        .01  0.5];%
                fop.StartPoint = [1.1*average_resp(end)    .40  2];%
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

            otherwise

                %%%% Fitting limits %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %                [ a (rmax)                K  n] %
                fop.Upper      = [         max_resp(end) .80  5];%
                fop.Lower      = [                    1  .05  1];%
                fop.StartPoint = [1.1*average_resp(end)  .40  2];%
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        end
        % fit
        try
            [f, gof] = fit(contrast,average_resp,fcn,fop);
        catch
            warning('Could not use fit(). Unit %d was not fit',u)
            flag = 1;
            break
        end

        PARAMS.(condition{cond}).fitobject(u).f = f;
        PARAMS.(condition{cond}).a(u) = f.a;
        PARAMS.(condition{cond}).k(u) = f.k;
        PARAMS.(condition{cond}).n(u) = f.n;
        PARAMS.(condition{cond}).rsquare(u) = gof.rsquare;
        PARAMS.(condition{cond}).gof(u) = gof;

    end

    if flag == 1
        continue
    end

    PARAMS.B(u) = B;


end
end

